@@ -1,5 +1,14 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
+"""
+Python-nvd3 is a Python wrapper for NVD3 graph library.
+NVD3 is an attempt to build re-usable charts and chart components
+for d3.js without taking away the power that d3.js gives you.
+
+Project location : https://github.com/areski/python-nvd3
+"""
+
 from optparse import OptionParser
 from string import Template
 import random
@@ -284,14 +293,6 @@ class NVD3Chart:
                         stab(3) + "tooltip_str = '<center><b>'+x+'</b></center>' + y;\n" +\
                         stab(3) + "return tooltip_str;\n" + \
                         stab(2) + "});\n"
-                elif self.model == 'lineChart':
-                    self.charttooltip = stab(2) + "chart.tooltipContent(function(key, y, e, graph) {\n" + \
-                        stab(3) + "var x = String(e);\n" +\
-                        stab(3) + "var y = String(graph.point.y);\n" +\
-                        self.tooltip_condition_string +\
-                        stab(3) + "tooltip_str = '<center><b>'+key+'</b></center>' + y + ' at ' + x;\n" +\
-                        stab(3) + "return tooltip_str;\n" + \
-                        stab(2) + "});\n"
                 else:
                     self.charttooltip = stab(2) + "chart.tooltipContent(function(key, y, e, graph) {\n" + \
                         stab(3) + "var x = String(graph.point.x);\n" +\
